diff src/frame.h @ 25544:693ca9ba497a

Change spelling of `toolbar' to `tool_bar' or `tool-bar'. Likewise for upper-case etc.
author Gerd Moellmann <gerd@gnu.org>
date Sun, 05 Sep 1999 15:49:07 +0000
parents 93b2f5b92137
children d02186608877
line wrap: on
line diff
--- a/src/frame.h	Sun Sep 05 15:48:57 1999 +0000
+++ b/src/frame.h	Sun Sep 05 15:49:07 1999 +0000
@@ -148,14 +148,14 @@
      toolkit support is available.  */
   Lisp_Object menu_bar_window;
 
-  /* A window used to display the toolbar of a frame.  */
-  Lisp_Object toolbar_window;
+  /* A window used to display the tool-bar of a frame.  */
+  Lisp_Object tool_bar_window;
 
-  /* Desired and current toolbar items.  */
-  Lisp_Object desired_toolbar_items, current_toolbar_items;
+  /* Desired and current tool-bar items.  */
+  Lisp_Object desired_tool_bar_items, current_tool_bar_items;
 
-  /* Desired and current contents displayed in toolbar_window.  */
-  Lisp_Object desired_toolbar_string, current_toolbar_string;
+  /* Desired and current contents displayed in tool_bar_window.  */
+  Lisp_Object desired_tool_bar_string, current_tool_bar_string;
 
   /* beyond here, there should be no more Lisp_Object components.  */
 
@@ -176,11 +176,11 @@
      be used for output.  */
   unsigned glyphs_initialized_p : 1;
 
-  /* Margin at the top of the frame.  Used to display the toolbar.  */
-  int toolbar_lines;
+  /* Margin at the top of the frame.  Used to display the tool-bar.  */
+  int tool_bar_lines;
 
-  int n_desired_toolbar_items;
-  int n_current_toolbar_items;
+  int n_desired_tool_bar_items;
+  int n_current_tool_bar_items;
   
   /* A buffer for decode_mode_line. */
   char *decode_mode_spec_buffer;
@@ -412,14 +412,14 @@
    These lines are counted in FRAME_HEIGHT.  */
 #define FRAME_MENU_BAR_LINES(f) (f)->menu_bar_lines
 
 /* Number of lines of frame F used for the toolbar.  */
 
-#define FRAME_TOOLBAR_LINES(f) (f)->toolbar_lines
+#define FRAME_TOOL_BAR_LINES(f) (f)->tool_bar_lines
 
 /* Lines above the top-most window in frame F.  */
 
 #define FRAME_TOP_MARGIN(F) \
-     (FRAME_MENU_BAR_LINES (F) + FRAME_TOOLBAR_LINES (F))
+     (FRAME_MENU_BAR_LINES (F) + FRAME_TOOL_BAR_LINES (F))
 
 /* Nonzero if this frame should display a menu bar
    in a way that does not use any text lines.  */
@@ -412,14 +412,14 @@
 #define FRAME_MENU_BAR_LINES(f) (f)->menu_bar_lines
 
-/* Number of lines of frame F used for the toolbar.  */
+/* Number of lines of frame F used for the tool-bar.  */
 